%global momorel 2

Summary: Tool for finding memory management bugs in programs
Name: valgrind
Version: 3.6.1
Release: %{momorel}m%{?dist}
#Patch1: valgrind-3.5.0-cachegrind-improvements.patch
#Patch2: valgrind-3.5.0-openat.patch
#Patch3: valgrind-3.5.0-glibc-2.10.1.patch
#Patch5: valgrind-3.5.0-stat.patch
License: GPLv2
Group: Development/Debuggers
URL: http://www.valgrind.org/
Source0: http://www.valgrind.org/downloads/%{name}-%{version}.tar.bz2 
NoSource: 0
# upstream patches exported from 
# svn://svn.valgrind.org/valgrind/branches/VALGRIND_3_6_BRANCH

### include local configuration
%{?include_specopt}

### default configurations
#  If you'd like to change these configurations, please copy them to
# ~/rpmbuild/specopt/valgrind.specopt and edit it.
%{?!do_test: %global do_test 1}
# Set 1 for svn snapshot version
%{?!rebuild_docs: %global rebuild_docs 0}
%{?!with_mpi: %global with_mpi 1}

Requires: glibc-debuginfo
%if %{do_test}
BuildRequires: glibc-debuginfo
%endif
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%ifarch x86_64 ppc64
# Ensure glibc{,-devel} is installed for both multilib arches
BuildRequires: /lib/libc.so.6 /usr/lib/libc.so /lib64/libc.so.6 /usr/lib64/libc.so
%endif
BuildRequires: glibc-devel >= 2.8
%if %{with_mpi}
# valgrind-3.4.0/auxprogs/libmpiwrap.c includes "mpi.h"
BuildRequires: mpich2-devel
BuildRequires: openmpi-devel >= 1.2.6
%endif
%if %{do_test}
BuildRequires: qt-devel
BuildRequires: boost-devel
BuildRequires: perl
%endif
%if %{rebuild_docs}
BuildRequires: docbook-style-xsl
BuildRequires: libxslt
%endif
ExclusiveArch: %{ix86} x86_64 ppc ppc64
%ifarch %{ix86}
%global valarch x86
%global valsecarch %{nil}
%endif
%ifarch x86_64
%global valarch amd64
%global valsecarch x86
%endif
%ifarch ppc
%global valarch ppc32
%global valsecarch ppc64
%endif
%ifarch ppc64
%global valarch ppc64
%global valsecarch ppc32
%endif

# Disable build root strip policy
%global __spec_install_post /usr/lib/rpm/momonga/brp-compress || :

# Disable -debuginfo package generation
%global debug_package %{nil}

%description
Valgrind is a tool to help you find memory-management problems in your
programs. When a program is run under Valgrind's supervision, all
reads and writes of memory are checked, and calls to
malloc/new/free/delete are intercepted. As a result, Valgrind can
detect a lot of problems that are otherwise very hard to
find/diagnose.

%package devel
Summary: Development files for valgrind
Group: Development/Debuggers
Requires: valgrind = %{version}-%{release}

%description devel
Header files and libraries for development of valgrind aware programs
or valgrind plugins.

%prep

print_specopt() {
## echo the specopt values
cat <<EOF
Configurations:
  do_test ............ %{do_test}
  rebuild_docs ....... %{rebuild_docs}
EOF
}
print_specopt

%setup -q -n valgrind-%{version}
#%%patch1 -p1 -b .cachegrind-improvements~
#%%patch2 -p1 -b .openat~
#%%patch3 -p1 -b .glibc-2.10.1~
#%%patch5 -p1 -b .stat~

%if %{rebuild_docs}
# modify some files
for x in `find -type f -name *.xml`; do
    sed --in-place=.doc~ -e 's,<title>\(.*\)<[^>]*>\(.*\)<[^>]*>\(.*\)</title>,<title>\1\2\3</title>,g' $x
done
sed --in-place=.doc~ -e 's,^XSL_MAN_STYLES =.*,XSL_MAN_STYLES = /usr/share/sgml/docbook/xsl-stylesheets-1.75.2/manpages/docbook.xsl \\,g' docs/Makefile.am
%endif

# patch2 and %%{rebuild_docs} requires this
#./autogen.sh

%build
%ifarch x86_64 ppc64
# Ugly hack - libgcc 32-bit package might not be installed
mkdir -p libgcc/32
touch libgcc/32/libgcc_s.a
touch libgcc/libgcc_s_32.a
%configure CC="gcc -B `pwd`/libgcc/" GDB=%{_bindir}/gdb
%else
%configure GDB=%{_bindir}/gdb
%endif

%make

%if %{rebuild_docs}
(cd docs && make html-docs man-pages)
%endif

# Ensure there are no unexpected file descriptors open,
# the testsuite otherwise fails.
cat > close_fds.c <<EOF
#include <stdlib.h>
#include <unistd.h>
int main (int argc, char *const argv[])
{
  int i, j = sysconf (_SC_OPEN_MAX);
  if (j < 0)
    exit (1);
  for (i = 3; i < j; ++i)
    close (i);
  execvp (argv[1], argv + 1);
  exit (1);
}
EOF
gcc %{optflags} -o close_fds close_fds.c

for i in `find . -type f \( -name *-amd64-linux -o -name *-x86-linux -o -name *-ppc*-linux \)`; do
  case "`file $i`" in
    *ELF*executable*statically\ linked*)
      objcopy -R .debug_loc -R .debug_frame -R .debug_ranges $i
  esac
done

# XXX pth_cancel2 hangs on x86_64
echo 'int main (void) { return 0; }' > none/tests/pth_cancel2.c

# test
%if %{do_test}
%check
make check || :
echo ===============TESTING===================
./close_fds make regtest || :
echo ===============END TESTING===============
%endif 

%install
rm -rf %{buildroot}
rm -rf docs.installed

%makeinstall
mkdir docs.installed
mv %{buildroot}%{_datadir}/doc/valgrind/* docs.installed/
rm -rf docs.installed/*.ps
rm -rf docs.installed/*.pdf

%if "%{valsecarch}" != ""
pushd $RPM_BUILD_ROOT%{_libdir}/valgrind/
rm -f *-%{valsecarch}-* || :
for i in *-%{valarch}-*; do
  j=`echo $i | sed 's/-%{valarch}-/-%{valsecarch}-/'`
%ifarch ppc
  ln -sf ../../lib64/valgrind/$j $j
%else
  ln -sf ../../lib/valgrind/$j $j
%endif
done
popd
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc COPYING NEWS README_*
%doc docs.installed/html
%{_bindir}/*
%dir %{_libdir}/valgrind
%{_libdir}/valgrind/*[^a]
%{_mandir}/man1/*

%files devel
%defattr(-,root,root)
%{_includedir}/valgrind
%{_libdir}/valgrind/*.a
%{_libdir}/pkgconfig/*

%changelog
* Sat Feb 19 2011 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.1-2m)
- add Requires: glibc-debuginfo

* Fri Feb 18 2011 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.1-1m)
- update to 3.6.1,  bug fix release

* Sun Nov 28 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-3m)
- rebuild for new GCC 4.5

* Wed Nov 03 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-2m)
- rebuild against boost-1.44.0

* Wed Oct 27 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-1m)
- update to 3.6.0 release version

* Fri Oct 15 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11444.1m)
- update to the latest snapshot

* Fri Sep 24 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11376.1m)
- update to the latest snapshot

* Thu Sep 16 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11358.1m)
- update to the latest snapshot

* Fri Aug 27 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11293.1m)
- update to the latest snapshot

* Sun Jul 25 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11227.1m)
- update to the latest snapshot

* Sat Jul 10 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11212.1m)
- update to the latest snapshot

* Sat Jun 26 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11188.2m)
- update vex r1985

* Fri Jun 25 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11188.1m)
- update to rev 11188

* Sun Jun 20 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-0.11181.1m)
- update to rev 11181
- change visioning style

* Sun May 30 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-4m)
- update to rev 11140

* Fri Apr 16 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-3m)
- update to rev 11104
-- see https://bugs.kde.org/show_bug.cgi?id=233565

* Sat Apr  3 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-2m)
- add manuals again

* Mon Mar 22 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.6.0-1m)
- update to development snapshot, which includes better glibc-2.11.90 supports
- temporally exclude some manuals because of its compilation failures

* Tue Mar  9 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.5.0-5m)
- modify for sys/stat.h

* Mon Nov 16 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.5.0-4m)
- fix compilation failure with glibc-2.11
-- please note that this fix is just a workaround.
  %%{_libdir}/valgrind/default.supp is not updated yet.

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.5.0-3m)
- rebuild against gcc-4.4 and glibc-2.11

* Sun Sep 20 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.5.0-2m)
- release %%dir %%{_libdir}/valgrind from package devel
- it's already provided by main package: valgrind and valgrind-devel Requires: valgrind
- License: GPLv2

* Thu Sep  3 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.5.0-1m)
- update to 3.5.0
- import three patches from fedora

* Mon Mar  2 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.4.1-1m)
- update to 3.4.1 (bug fix release)
- delete Patch2, which no longer seems to be required.

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.4.0-2m)
- rebuild against rpm-4.6

* Mon Jan  5 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.4.0-1m)
- [SECURITY] CVE-2008-4865
- update to 3.4.0
- revise spec

* Sat Dec  6 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.3.1-2m)
- add support for glibc 2.9

* Thu Jun  5 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.3.1-1m)
- update 3.3.1
-- fixes many bugs
-- adds support for the SSSE3 (Core 2) instruction set
- delete patches

* Thu May  8 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (3.3.0-6m)
- rebuild against openmpi-1.2.6

* Thu Apr 17 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.3.0-5m)
- remove epoch to resolve dependency

* Thu Apr 17 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.3.0-4m)
- merge changes from fc-devel (valgrind-3_3_0-3)
- * Wed Apr 16 2008 Jakub Jelinek <jakub@redhat.com> 3.3.0-3
- - add suppressions for glibc 2.8
- - add a bunch of syscall wrappers (#441709)
- * Mon Mar  3 2008 Jakub Jelinek <jakub@redhat.com> 3.3.0-2
- - add _dl_start suppression for ppc/ppc64
- * Mon Mar  3 2008 Jakub Jelinek <jakub@redhat.com> 3.3.0-1
- - update to 3.3.0
- - split off devel bits into valgrind-devel subpackage

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.3.0-3m)
- rebuild against gcc43

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (3.3.0-3m)
- %%NoSource -> NoSource

* Sat Jan 12 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.3.0-2m)
- use mpich2-devel instead of mpich-devel

* Sat Dec 15 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.3.0-1m)
- updated to 3.3.0
-- deleted all patches and autoconf hack

* Mon Oct 22 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.3-7m)
- updated default.supp for glibc-2.7

* Thu Oct 18 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.3-6m)
- sync with fc-devel (valgrind-3_2_3-7)
--* Thu Oct 18 2007 Jakub Jelinek <jakub@redhat.com> 3.2.3-7
--- add suppressions for glibc >= 2.7

* Mon Sep  3 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.3-5m)
- sync with fc-devel (valgrind-3_2_3-6)
--* Fri Aug 31 2007 Jakub Jelinek <jakub@redhat.com> 3.2.3-6
--- handle new x86_64 nops (#256801, KDE#148447)
--- add support for private futexes (KDE#146781)
--* Fri Aug  3 2007 Jakub Jelinek <jakub@redhat.com> 3.2.3-5
--- add ppc64-linux symlink in valgrind ppc.rpm, so that when
---  rpm prefers 32-bit binaries over 64-bit ones 32-bit
--- /usr/bin/valgrind can find 64-bit valgrind helper binaries (#249773)
--- power5-- and power6 support (#240762)

* Wed Jul  4 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.2.3-4m)
- move %%check place for configure option %%do_test

* Sat Jun 30 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.3-3m)
- sync with fc-devel (valgrind-3_2_3-4)
-- add valgrind-3.2.3-io_destroy.patch

* Wed May 23 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.3-2m)
- add workaround support for glibc-2.6

* Wed Feb 14 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.3-1m)
- sync with fc-devel (valgrind-3_2_3-2)	
--* Tue Feb 13 2007 Jakub Jelinek <jakub@redhat.com> 3.2.3-2
--- fix valgrind.pc again
--* Tue Feb 13 2007 Jakub Jelinek <jakub@redhat.com> 3.2.3-1
--- update to 3.2.3

* Fri Nov 10 2006 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.1-4m)
- sync with fc-devel (valgrind-3.2.1-7)
-* Wed Nov  8 2006 Jakub Jelinek <jakub@redhat.com> 3.2.1-7
-- some cachegrind improvements (Ulrich Drepper)

* Wed Nov  8 2006 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.1-3m)
- sync with fc-devel (valgrind-3.2.1-6)
-* Mon Nov  6 2006 Jakub Jelinek <jakub@redhat.com> 3.2.1-6
-- fix valgrind.pc (#213149)
-- handle Intel Core2 cache sizes in cachegrind (Ulrich Drepper)

* Thu Oct 26 2006 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.1-2m)
- sync with fc-devel (valgrind-3.2.1-5)
-* Wed Oct 25 2006 Jakub Jelinek <jakub@redhat.com> 3.2.1-5
-- fix valgrind on ppc/ppc64 where PAGESIZE is 64K (#211598)

* Sat Oct 14 2006 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (3.2.1-1m)
- update to 3.2.1

* Sun Jul 16 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (3.1.0-2m)
- enable x86_64

* Sun Dec 11 2005 Koichi NARITA <pulsar@sea.plala.or.jp>
- (3.1.0-1m)
- update to 3.1.0

* Sat Nov  6 2004 TAKAHASHI Tamotsu <tamo>
- (2.2.0-1m)
- new stable version

* Sat Mar 27 2004 Toru Hoshina <t@momonga-linux.org>
- (2.1.0-2m)
- revised spec for rpm 4.2.

* Fri Dec 26 2003 Kazuhiko <kazuhiko@fdiary.net>
- (2.1.0-1m)
- initial import to Momonga
